@@ -6,10 +6,13 @@ from .utils import get_method_from_module, format_path_to_module
 from .data import load_data_from_path
 from .template import TemplateSet
 
+import logging
+
 DEFAULT_DATA_DIRECTORY = os.path.join(os.curdir, 'data')
 DEFAULT_TEMPLATE_DIRECTORY = os.path.join(os.curdir, 'templates')
 DEFAULT_SCRIPTS_DIRECTORY = os.path.join(os.curdir, 'scripts')
 
+LOGGER = logging.getLogger(__name__)
 
 class MiuraScript(object):
 
@@ -38,6 +41,9 @@ class MiuraScript(object):
 
         if self.delete:
             target_method = 'delete'
+        if self.dry_run:
+            LOGGER.info("Performing a Dry Run! No Jobs Are Being Created")
+            target_method = 'print_info'
         else:
             target_method = 'upsert'
 
